## libdave

This repository contains the JS and C++ libraries which together implement Discord's Audio & Video End-to-End Encryption (DAVE) protocol. These libraries are leveraged by Discord's native clients to support the DAVE protocol.

The DAVE protocol is described in detail in the [protocol whitepaper](https://github.com/discord/dave-protocol).

See the [cpp README](/cpp/README.md) or the [js README](/js/README.md) for information specific to each library.